==> scrubr_0.1.1.tar.gz: scrubr/R/scrubr_datasets.R <==
#' scrubr datasets
#'
#' \itemize{
#'  \item \code{\link{sample_data_1}}
#'  \item \code{\link{sample_data_2}}
#'  \item \code{\link{sample_data_3}}
#'  \item \code{\link{sample_data_4}}
#' }
#' @name scrubr_datasets
#' @keywords datasets
NULL

#' Sample data.frame 1
#'
#' @format A data frame with 1500 rows and 5 variables:
#' \describe{
#'   \item{name}{taxonomic name}
#'   \item{longitude}{longitude, decimal degree}
#'   \item{latitude}{latitude, decimal degree}
#'   \item{date}{date, date the occurrence was recorded}
#'   \item{key}{occurrence key}
#' }
#'
#' Data originally collected from GBIF
#' @name sample_data_1
#' @docType data
#' @keywords datasets internal
NULL

#' Sample data.frame number 2
#'
#' @format A data frame with 1500 rows and 7 variables:
#' \describe{
#'   \item{name}{taxonomic name}
#'   \item{longitude}{longitude, decimal degree}
#'   \item{latitude}{latitude, decimal degree}
#'   \item{key}{occurrence key}
#'   \item{year}{year of occurrence}
#'   \item{month}{month of occurrence}
#'   \item{day}{day of occurrence}
#' }
#'
#' Data originally collected from GBIF
#' @name sample_data_2
#' @docType data
#' @keywords datasets internal
NULL

#' Sample data.frame number 3
#'
#' @format A data frame with 200 rows and 5 variables:
#' \describe{
#'   \item{name}{taxonomic name}
#'   \item{decimalLatitude}{latitude, decimal degree}
#'   \item{decimalLongitude}{longitude, decimal degree}
#'   \item{key}{occurrence key}
#'   \item{eventDate}{date, date the occurrence was recorded}
#' }
#'
#' Data originally collected from GBIF
#' @name sample_data_3
#' @docType data
#' @keywords datasets internal
NULL

#' Sample data.frame number 4
#'
#' @format A data frame with 100 rows and 6 variables:
#' \describe{
#'   \item{name}{taxonomic name}
#'   \item{decimalLatitude}{latitude, decimal degree}
#'   \item{decimalLongitude}{longitude, decimal degree}
#'   \item{key}{occurrence key}
#'   \item{eventDate}{date, date the occurrence was recorded}
#'   \item{country}{country of occurrence record}
#' }
#'
#' Data originally collected from GBIF
#' @name sample_data_4
#' @docType data
#' @keywords datasets internal
NULL

==> scrubr_0.3.0.tar.gz: scrubr/R/scrubr_datasets.R <==
#' scrubr datasets
#'
#' - [sample_data_1]
#' - [sample_data_2]
#' - [sample_data_3]
#' - [sample_data_4]
#' - [sample_data_6]
#'
#' @name scrubr_datasets
#' @keywords datasets
NULL

#' Sample data.frame 1
#'
#' @format A data frame with 1500 rows and 5 variables:
#' \describe{
#'   \item{name}{taxonomic name}
#'   \item{longitude}{longitude, decimal degree}
#'   \item{latitude}{latitude, decimal degree}
#'   \item{date}{date, date the occurrence was recorded}
#'   \item{key}{occurrence key}
#' }
#'
#' Data originally collected from GBIF
#' @name sample_data_1
#' @docType data
#' @keywords datasets internal
NULL

#' Sample data.frame number 2
#'
#' @format A data frame with 1500 rows and 7 variables:
#' \describe{
#'   \item{name}{taxonomic name}
#'   \item{longitude}{longitude, decimal degree}
#'   \item{latitude}{latitude, decimal degree}
#'   \item{key}{occurrence key}
#'   \item{year}{year of occurrence}
#'   \item{month}{month of occurrence}
#'   \item{day}{day of occurrence}
#' }
#'
#' Data originally collected from GBIF
#' @name sample_data_2
#' @docType data
#' @keywords datasets internal
NULL

#' Sample data.frame number 3
#'
#' @format A data frame with 200 rows and 5 variables:
#' \describe{
#'   \item{name}{taxonomic name}
#'   \item{decimalLatitude}{latitude, decimal degree}
#'   \item{decimalLongitude}{longitude, decimal degree}
#'   \item{key}{occurrence key}
#'   \item{eventDate}{date, date the occurrence was recorded}
#' }
#'
#' Data originally collected from GBIF
#' @name sample_data_3
#' @docType data
#' @keywords datasets internal
NULL

#' Sample data.frame number 4
#'
#' @format A data frame with 100 rows and 6 variables:
#' \describe{
#'   \item{name}{taxonomic name}
#'   \item{decimalLatitude}{latitude, decimal degree}
#'   \item{decimalLongitude}{longitude, decimal degree}
#'   \item{key}{occurrence key}
#'   \item{eventDate}{date, date the occurrence was recorded}
#'   \item{country}{country of occurrence record}
#' }
#'
#' Data originally collected from GBIF
#' @name sample_data_4
#' @docType data
#' @keywords datasets internal
NULL

#' Sample data.frame number 5
#'
#' @format A data frame with 39 rows and 5 variables:
#' \describe{
#'   \item{name}{taxonomic name}
#'   \item{longitude}{longitude, decimal degree}
#'   \item{latitude}{latitude, decimal degree}
#'   \item{date}{date, date the occurrence was recorded}
#'   \item{key}{GBIF occurrence key}
#' }
#'
#' Data originally collected from GBIF
#' @name sample_data_5
#' @docType data
#' @keywords datasets internal
NULL

#' Sample data.frame number 6
#'
#' @format A data frame with 50 rows and 5 variables:
#' \describe{
#'   \item{name}{taxonomic name}
#'   \item{key}{GBIF occurrence key}
#'   \item{decimalLatitude}{latitude, decimal degree}
#'   \item{decimalLongitude}{longitude, decimal degree}
#'   \item{coordinateUncertaintyInMeters}{Uncertainity, the point-radius representation of the location}
#' }
#'
#' Data originally collected from GBIF
#' @name sample_data_6
#' @docType data
#' @keywords datasets internal
NULL

#' Sample data.frame number 7
#'
#' @format A data frame with 50 rows and 91 variables
#'
#' Data originally collected from GBIF
#' @name sample_data_7
#' @docType data
#' @keywords datasets internal
NULL
